@@ -231,13 +231,12 @@ namespace System.Net.Http
         private static void OnRequestSendingRequest(WinHttpRequestState state)
         {
             Debug.Assert(state != null, "OnRequestSendingRequest: state is null");
-            Debug.Assert(state.RequestHandle != null, "OnRequestSendingRequest: state.RequestHandle is null");
             Debug.Assert(state.RequestMessage != null, "OnRequestSendingRequest: state.RequestMessage is null");
             Debug.Assert(state.RequestMessage.RequestUri != null, "OnRequestSendingRequest: state.RequestMessage.RequestUri is null");
 
-            if (state.RequestMessage.RequestUri.Scheme != UriScheme.Https)
+            if (state.RequestMessage.RequestUri.Scheme != UriScheme.Https || state.RequestHandle == null)
             {
-                // Not SSL/TLS.
+                // Not SSL/TLS or request already gone
                 return;
             }
 
